@@ -29,7 +29,7 @@ API_REQUEST_FIELDS = {
         'group',
         'actor_refs',
         'mark_as_spam_id',
-        'like_info',
+        'like_summary',
         'photo_main',
         'photo_refs',
         'album_refs',
@@ -48,12 +48,12 @@ API_REQUEST_FIELDS = {
         'author_type',
         'created',
         'group_id',
-        # Next one yeild 'attrs' attribute in OK server response. 
+        # Next one yeild 'attrs' attribute in OK server response.
         'like_allowed',
         'like_summary',
         'photos_count',
         # Next one present in docs still its meaning is unknown
-        'ref', 
+        'ref',
         'title',
         'user_id',
         # Next 3 are documented. Still yeild no results for group album
@@ -74,17 +74,17 @@ API_REQUEST_FIELDS = {
         'like_summary',
         # Undocumented alas retuned in resp to group_photo.*
         'liked_it',
-        # Next 2 yeild 'attrs' attribute in OK server response. 
-        'like_allowed', 
+        # Next 2 yeild 'attrs' attribute in OK server response.
+        'like_allowed',
         'mark_as_spam_allowed',
         # Next one is undocumented. Returned in response to fields: group_photo.*
-        'pic1024max', 
+        'pic1024max',
         'pic1024x768',
         'pic128max',
         'pic128x128',
         'pic180min',
         # Next one present in docs. Still yeilds no results for group photos.getPhotos
-        'pic190x190', 
+        'pic190x190',
         'pic240min',
         'pic320min',
         'pic50x50',
